
penman.models.noop
==================

.. automodule:: penman.models.noop

.. autoclass:: NoOpModel
   :show-inheritance:
   :members:

.. data:: model

   An instance of the :class:`NoOpModel` class.
